==> jc-1.4.0.tar.gz: gnu/java/lang/ClassHelper.h <==
// public class gnu.java.lang.ClassHelper

// class file dependencies
// @dep_class 1c9c00f380cfa59 gnu_java_lang_ClassHelper
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_ClassHelper_H_
#define _JC_gnu_java_lang_ClassHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_lang_ClassHelper$sub_refs	_jc_gnu_java_lang_ClassHelper$sub_refs;
typedef struct _jc_gnu_java_lang_ClassHelper$sub_nonrefs	_jc_gnu_java_lang_ClassHelper$sub_nonrefs;
typedef struct _jc_gnu_java_lang_ClassHelper$refs	_jc_gnu_java_lang_ClassHelper$refs;
typedef struct _jc_gnu_java_lang_ClassHelper$nonrefs	_jc_gnu_java_lang_ClassHelper$nonrefs;
typedef struct _jc_gnu_java_lang_ClassHelper$object	_jc_gnu_java_lang_ClassHelper$object;

typedef struct _jc_gnu_java_lang_ClassHelper$fields_struct	_jc_gnu_java_lang_ClassHelper$fields_struct;
typedef const struct _jc_gnu_java_lang_ClassHelper$vmethods	_jc_gnu_java_lang_ClassHelper$vmethods;
typedef const struct _jc_gnu_java_lang_ClassHelper$vtable	_jc_gnu_java_lang_ClassHelper$vtable;
typedef const struct _jc_gnu_java_lang_ClassHelper$vtype	_jc_gnu_java_lang_ClassHelper$vtype;

// Class fields structure
struct _jc_gnu_java_lang_ClassHelper$fields_struct {
	struct _jc_object	*allFields;
	struct _jc_object	*allMethods;
};
extern _jc_gnu_java_lang_ClassHelper$fields_struct _jc_gnu_java_lang_ClassHelper$class_fields;

// Constructors
extern void _jc_gnu_java_lang_ClassHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_lang_ClassHelper$object *);

// Static methods
extern void _jc_gnu_java_lang_ClassHelper$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern _jc_object_array *_jc_gnu_java_lang_ClassHelper$method$getAllFields$d41f737415e9185b(_jc_env *, struct _jc_java_lang_Class$object *);
extern _jc_object_array *_jc_gnu_java_lang_ClassHelper$method$getAllMethods$1da021c5527a77d3(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_ClassHelper$method$getTruncatedClassName$21b4ad3141fd3938(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_ClassHelper$method$getTruncatedName$2ca796530ffeb8cd(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_java_lang_ClassHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_lang_ClassHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_ClassHelper$vmethods	gnu_java_lang_ClassHelper;
};

// Vtype
struct _jc_gnu_java_lang_ClassHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_ClassHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_ClassHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_ClassHelper$refs {
    _jc_gnu_java_lang_ClassHelper$sub_refs	gnu_java_lang_ClassHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_ClassHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_ClassHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_ClassHelper$sub_nonrefs	gnu_java_lang_ClassHelper;
};

// Object instance structure
struct _jc_gnu_java_lang_ClassHelper$object {
	_jc_gnu_java_lang_ClassHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_ClassHelper$vtype	*vtype;
	_jc_gnu_java_lang_ClassHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_ClassHelper$vtype _jc_gnu_java_lang_ClassHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_ClassHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_ClassHelper$class_object;

#endif	/* _JC_gnu_java_lang_ClassHelper_H_ */

==> jc-1.4.6.tar.gz: gnu/java/lang/ClassHelper.h <==
// public class gnu.java.lang.ClassHelper

// class file dependencies
// @dep_class 1c9c00f380cfa59 gnu_java_lang_ClassHelper
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_ClassHelper_H_
#define _JC_gnu_java_lang_ClassHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_gnu_java_lang_ClassHelper$sub_refs	_jc_gnu_java_lang_ClassHelper$sub_refs;
typedef struct _jc_gnu_java_lang_ClassHelper$sub_nonrefs	_jc_gnu_java_lang_ClassHelper$sub_nonrefs;
typedef struct _jc_gnu_java_lang_ClassHelper$refs	_jc_gnu_java_lang_ClassHelper$refs;
typedef struct _jc_gnu_java_lang_ClassHelper$nonrefs	_jc_gnu_java_lang_ClassHelper$nonrefs;
typedef struct _jc_gnu_java_lang_ClassHelper$object	_jc_gnu_java_lang_ClassHelper$object;

typedef struct _jc_gnu_java_lang_ClassHelper$fields_struct	_jc_gnu_java_lang_ClassHelper$fields_struct;
typedef const struct _jc_gnu_java_lang_ClassHelper$vmethods	_jc_gnu_java_lang_ClassHelper$vmethods;
typedef const struct _jc_gnu_java_lang_ClassHelper$vtable	_jc_gnu_java_lang_ClassHelper$vtable;
typedef const struct _jc_gnu_java_lang_ClassHelper$vtype	_jc_gnu_java_lang_ClassHelper$vtype;

// Class fields structure
struct _jc_gnu_java_lang_ClassHelper$fields_struct {
	struct _jc_object	*allFields;
	struct _jc_object	*allMethods;
};
extern _jc_gnu_java_lang_ClassHelper$fields_struct _jc_gnu_java_lang_ClassHelper$class_fields;

// Constructors
extern void _jc_gnu_java_lang_ClassHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_lang_ClassHelper$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_java_lang_ClassHelper$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_lang_ClassHelper$method$getAllFields$d41f737415e9185b(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_gnu_java_lang_ClassHelper$method$getAllMethods$1da021c5527a77d3(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_ClassHelper$method$getTruncatedClassName$21b4ad3141fd3938(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_ClassHelper$method$getTruncatedName$2ca796530ffeb8cd(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_lang_ClassHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_lang_ClassHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_ClassHelper$vmethods	gnu_java_lang_ClassHelper;
};

// Vtype
struct _jc_gnu_java_lang_ClassHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_ClassHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_ClassHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_ClassHelper$refs {
    _jc_gnu_java_lang_ClassHelper$sub_refs	gnu_java_lang_ClassHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_ClassHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_ClassHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_ClassHelper$sub_nonrefs	gnu_java_lang_ClassHelper;
};

// Object instance structure
struct _jc_gnu_java_lang_ClassHelper$object {
	_jc_gnu_java_lang_ClassHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_ClassHelper$vtype	*vtype;
	_jc_gnu_java_lang_ClassHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_ClassHelper$vtype _jc_gnu_java_lang_ClassHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_ClassHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_ClassHelper$class_object;

#endif	/* _JC_gnu_java_lang_ClassHelper_H_ */
